function paperexample ()

% These examples use the procedures of butools v2

    function [Q, R] = buildOnOff (meanOn, meanOff, rate, baserate, K)
        
        Q = zeros(K);
        R = zeros(K);
        for i=1:K
            if i<K
                Q(i,i+1) = (K-i) / meanOn;
            end
            if i>1
                Q(i,i-1) = (i-1) / meanOff;
            end
            R(i,i) = baserate + (i-1)*rate/K;
        end
        Q = Q - diag(sum(Q,2));
    end

    % EXAMPLE 1.
    % ==========
    % call the "independent" solvers

    disp('----------------------')
    disp('-     EXAMPLE 1      -')
    disp('----------------------')
    
    Kin = 20;
    Kout = 10;
    
    % expected value = K*lambda/(lambda+mu) = Eoff/(Eon+Eoff)
    [Qin, Rin] = buildOnOff (2.0, 1.0, 10.0, 0, Kin);
    [Qout, Rout] = buildOnOff (20.0, 30.0, 8.0, 0.1, Kout);
    lambda = sum(CTMCSolve(Qin)*Rin);
    mu = sum(CTMCSolve(Qout)*Rout);
    utilization = lambda/mu
    x = (0:0.05:3)';

    disp('Running analysis with boundary-continuous policy');
    t1 = clock();
    [alpha,A] = FluFluSTD(Qin, Rin, Qout, Rout, false);
    t2 = clock();
    fprintf ('analysis time = %g\n', etime(t2,t1));
    moms = MomentsFromME(alpha,A,5)
    y = CdfFromME(alpha, A, x);
   
    disp('Running analysis with boundary-proportional policy');
    t1 = clock();
    [alpha0,A0] = FluFluSTD(Qin, Rin, Qout, Rout, true);
    t2 = clock();
    fprintf ('analysis time = %g\n', etime(t2,t1));
    moms0 = MomentsFromME(alpha0,A0,5)
    y0 = CdfFromME(alpha0, A0, x);
   
    % plot results and save it to file
    plot(x,y,x,y0);
    dlmwrite('plotdata.txt',[x,y,y0],'\t');

    % EXAMPLE 2.
    % ==========
    % call both the "independent" and the "dependent" solvers for the
    % independent example
    % we should see that they both give the same result
    % however, the dependent solver is much slower and gives back huge
    % matrices

    disp('----------------------')
    disp('-     EXAMPLE 2      -')
    disp('----------------------')

    Kin = 11;
    Kout = 8;
    [Qin, Rin] = buildOnOff (2.0, 1.0, 10.0, 0, Kin);
    [Qout, Rout] = buildOnOff (20.0, 30.0, 8.0, 0.1, Kout);
    lambda = sum(CTMCSolve(Qin)*Rin);
    mu = sum(CTMCSolve(Qout)*Rout);
    utilization = lambda/mu
    
    disp('Running "dependent" solver');
    t1 = clock();
    Iin = eye(size(Qin));
    Iout = eye(size(Qout));
    [alpha,A] = FluidQueueSTD (kron(Qin,Iout)+kron(Iin,Qout), kron(Rin,Iout), kron(Iin,Rout));
    t2 = clock();   
    fprintf ('analysis time = %g\n', etime(t2,t1));
    moms = MomentsFromME(alpha,A,5)

    disp('Running "independent" solver');
    t1 = clock();
    [alpha,A] = FluFluSTD(Qin, Rin, Qout, Rout, false);
    t2 = clock();
    fprintf ('analysis time = %g\n', etime(t2,t1));
    moms = MomentsFromME(alpha,A,5)

end

